==> tr-lang-0.1.5.crate: tr-lang-0.1.5/README.md <==
# tr-lang

### Made with ❤️ in 🇹🇷

tr-lang is a language that aims to bring programming language syntax closer to Turkish.
tr-lang is a stack based language and uses reverse-polish notation for maths.

# What has been Implemented?

#### ✔️ tr-lang lexer seems like its done [Issue #1](https://github.com/kaiserthe13th/tr-lang/issues/1#issue-1027652152)<br>
#### 🕘 tr-lang parser is in progress [Issue #2](https://github.com/kaiserthe13th/tr-lang/issues/2#issue-1027660436)<br>
#### ❌ tr-lang bytecode is not implemented [Issue #3](https://github.com/kaiserthe13th/tr-lang/issues/3#issue-1027661753)<br>
#### ❌ tr-lang bytecode reader is not implemented [Issue #4](https://github.com/kaiserthe13th/tr-lang/issues/4#issue-1027663331)<br>
#### ❌ tr-lang runtime is not implemented [Issue #5](https://github.com/kaiserthe13th/tr-lang/issues/5#issue-1027665033)<br>

# Installation

## Homebrew
```sh
brew tap kaiserthe13th/tr-lang
brew install tr-lang
```

## Cargo
```sh
cargo install tr-lang
```

## Build from source
dependencies: `rust, cargo`

```sh
git clone https://github.com/kaiserthe13th/tr-lang
cd tr-lang
cargo build --release
```
your file will be in target/release/tr-lang

# [Specification](https://github.com/kaiserthe13th/tr-lang/wiki/Specification-EN)
# [See the Wiki](https://github.com/kaiserthe13th/tr-lang/wiki)

# Thanks

I give my thanks to user [Netwave](https://stackoverflow.com/users/1695172/netwave) from stackoverflow.com for helping fix a [bug](https://stackoverflow.com/questions/69635458/pattern-matching-does-not-allow-me-to-change-values/69636181#69636181) during the creation of the parser.

==> tr-lang-0.2.3.crate: tr-lang-0.2.3/README.md <==
# tr-lang

### Made with ❤️ in 🇹🇷

tr-lang is a language that aims to bring programming language syntax closer to Turkish.
tr-lang is a stack based language and uses reverse-polish notation for maths.

# What has been Implemented?

#### ✔️ tr-lang lexer seems like its done [Issue #1](https://github.com/kaiserthe13th/tr-lang/issues/1#issue-1027652152)<br>
#### ✔️ tr-lang parser is in progress [Issue #2](https://github.com/kaiserthe13th/tr-lang/issues/2#issue-1027660436)<br>
#### ✔️ tr-lang bytecode seems like its done [Issue #3](https://github.com/kaiserthe13th/tr-lang/issues/3#issue-1027661753)<br>
#### ✔️ tr-lang bytecode reader seems like its done [Issue #4](https://github.com/kaiserthe13th/tr-lang/issues/4#issue-1027663331)<br>
#### 🕘 tr-lang runtime is in progress [Issue #5](https://github.com/kaiserthe13th/tr-lang/issues/5#issue-1027665033)<br>

# Installation

## Homebrew
```sh
brew tap kaiserthe13th/tr-lang
brew install tr-lang
```

## Cargo
```sh
cargo install tr-lang
```

## Build from source
dependencies: `rust, cargo`

```sh
git clone https://github.com/kaiserthe13th/tr-lang
cd tr-lang
cargo build --release
```
your file will be in target/release/tr-lang

# [Specification](https://github.com/kaiserthe13th/tr-lang/wiki/Specification-EN)
# [See the Wiki](https://github.com/kaiserthe13th/tr-lang/wiki)

# Thanks

I give my thanks to user [Netwave](https://stackoverflow.com/users/1695172/netwave) from stackoverflow.com for helping fix a [bug](https://stackoverflow.com/questions/69635458/pattern-matching-does-not-allow-me-to-change-values/69636181#69636181) during the creation of the parser.
